@@ -1,4 +1,5 @@
 import json
+from string import Formatter
 from typing import Dict
 
 import pyspark.sql.types as T
@@ -61,6 +62,22 @@ class SchemaManager(metaclass=Singleton):
 
         # Check if the schema is a sql string
         if key == "sql":
+            # Check for substitutions like {} contained in the value:
+            other_schema_keys = set(
+                i[1] for i in Formatter().parse(value) if i[1] is not None
+            )
+            replacements = {}
+            for other_key in other_schema_keys:
+                if other_key.endswith("_schema"):
+                    other_base_key = other_key[: -len("_schema")]
+                    replacements[other_key] = self.get_schema_as_string(other_base_key)
+                else:
+                    replacements[other_key] = Configurator().get_all_details()[
+                        other_key
+                    ]
+            if replacements:
+                value = value.format(**replacements)
+
             parsed_schema = T._parse_datatype_string(value)
             if not isinstance(parsed_schema, T.StructType):
                 raise FalseSchemaDefinitionException()
@@ -93,6 +110,7 @@ class SchemaManager(metaclass=Singleton):
         return str_schema
 
     def get_schema_as_string(self, schema_identifier: str) -> str:
+        "return schema as a sql schema string"
         schema = self.get_schema(schema_identifier)
 
         str_schema = self._schema_to_spark_sql(schema)
